@@ -34,11 +34,10 @@ impl<Input, Output> Awaitable<Input, Output> {
 }
 
 impl<Input: Debug, Output: Debug> Awaitable<Input, Output> {
-    /// Reset `Awaitable` to its initial state, equivalent to
-    /// calling `Self::new(input)` again.
+    /// Reset `Awaitable` to its initial state.
     ///
     /// After this call, `install_waker`, `take_input` and `done`
-    /// can be called again.
+    /// can be called.
     pub fn reset(&self, input: Option<Input>) {
         *self.0.lock() = InnerState::Ongoing(input, None);
     }
@@ -46,7 +45,6 @@ impl<Input: Debug, Output: Debug> Awaitable<Input, Output> {
     /// Return true if the task is already done.
     ///
     /// **
-    /// `install_waker` must not be registered twice.
     /// `install_waker` must not be called after `take_output` is called.
     /// **
     pub fn install_waker(&self, waker: Waker) -> Result<bool, Error> {
@@ -58,12 +56,8 @@ impl<Input: Debug, Output: Debug> Awaitable<Input, Output> {
             Uninitialized => Err(Error::Uninitialized),
 
             Ongoing(_input, stored_waker) => {
-                if stored_waker.is_some() {
-                    Err(Error::WakerAlreadyInstalled)
-                } else {
-                    *stored_waker = Some(waker);
-                    Ok(false)
-                }
+                *stored_waker = Some(waker);
+                Ok(false)
             }
             Done(_) => Ok(true),
             Consumed => Err(Error::AlreadyConsumed),
@@ -124,4 +118,9 @@ impl<Input: Debug, Output: Debug> Awaitable<Input, Output> {
     pub fn is_done(&self) -> bool {
         matches!(&*self.0.lock(), InnerState::Done(_))
     }
+
+    /// Return true if current state is `Consumed`.
+    pub fn is_consumed(&self) -> bool {
+        matches!(&*self.0.lock(), InnerState::Consumed)
+    }
 }
